from scraper import instagram_profile_json

print(instagram_profile_json("tomcruise"))